@@ -1,4 +1,4 @@
-from .base import GraphQLHandler, GraphQLWebsocketHandler
+from .base import GraphQLHandler, GraphQLHttpHandlerBase, GraphQLWebsocketHandler
 from .http import GraphQLHTTPHandler
 from .graphql_transport_ws import GraphQLTransportWSHandler
 from .graphql_ws import GraphQLWSHandler
@@ -7,6 +7,7 @@ from .graphql_ws import GraphQLWSHandler
 __all__ = [
     "GraphQLHandler",
     "GraphQLHTTPHandler",
+    "GraphQLHttpHandlerBase",
     "GraphQLTransportWSHandler",
     "GraphQLWSHandler",
     "GraphQLWebsocketHandler",
