@@ -23,8 +23,9 @@ _i_token_description_single_line = r"(?:\"(?:[^\"\n\r])*?\")"
 
 _r_directive_definition = re.compile(
     "("
-    f"{_i_token_delimiter}"
-    f"(?:{_i_token_description_block_string}|{_i_token_description_single_line})??"
+    f"(?:{_i_token_delimiter}(?:"
+    f"{_i_token_description_block_string}|{_i_token_description_single_line}"
+    "))??"
     f"{_i_token_delimiter}directive"
     f"(?:{_i_token_delimiter})?@({_i_token_name})"
     f"(?:(?:{_i_token_delimiter})?{_i_token_arguments})?"
@@ -57,6 +58,8 @@ _allowed_directives = [
     "tag",  # Federation 2 directive.
     "override",  # Federation 2 directive.
     "inaccessible",  # Federation 2 directive.
+    "composeDirective",  # Federation 2.1 directive.
+    "interfaceObject",  # Federation 2.3 directive.
 ]
 
 
@@ -79,7 +82,7 @@ def resolve_entities(_: Any, info: GraphQLResolveInfo, **kwargs) -> Any:
         type_object = info.schema.get_type(__typename)
 
         if not type_object or not isinstance(type_object, GraphQLObjectType):
-            raise Exception(
+            raise TypeError(
                 f"The `_entities` resolver tried to load an entity for"
                 f' type "{__typename}", but no object type of that name'
                 f" was found in the schema",
