@@ -6,6 +6,7 @@ from typing import (
     List,
     Mapping,
     Optional,
+    Tuple,
     Type,
     TypeVar,
     Union,
@@ -49,18 +50,18 @@ VisitableSchemaType = Union[
 ]
 V = TypeVar("V", bound=VisitableSchemaType)
 VisitableMap = Dict[str, V]
-IndexedObject = Union[VisitableMap, List[V]]
+IndexedObject = Union[VisitableMap, Tuple[V, ...]]
 
 
 Callback = Callable[..., Any]
 
 
-def each(list_or_dict: IndexedObject, callback: Callback):
-    if isinstance(list_or_dict, list):
-        for value in list_or_dict:
+def each(tuple_or_dict: IndexedObject, callback: Callback):
+    if isinstance(tuple_or_dict, tuple):
+        for value in tuple_or_dict:
             callback(value)
     else:
-        for key, value in list_or_dict.items():
+        for key, value in tuple_or_dict.items():
             callback(value, key)
 
 
@@ -173,7 +174,6 @@ def visit_schema(
         method_name: str, type_: VisitableSchemaType, *args: Any
     ) -> Union[VisitableSchemaType, Literal[False]]:
         for visitor in visitor_selector(type_, method_name):
-
             new_type = getattr(visitor, method_name)(type_, *args)
             if new_type is None:
                 # Keep going without modifying type.
@@ -281,12 +281,14 @@ def visit_schema(
             # an instanceof check, so we have to visit the fields in this lexical
             # context, so that TypeScript can validate the call to
             # visit_field_definition.
-            new_field = call_method("visit_field_definition", field, type_)
+            new_field = cast(
+                GraphQLField, call_method("visit_field_definition", field, type_)
+            )
             # While any field visitor needs a reference to the field object, some
             # field visitors may also need to know the enclosing (parent) type,
             # perhaps to determine if the parent is a GraphQLObjectType or a
             # GraphQLInterfaceType. To obtain a reference to the parent, a
-            # visitor method can have a second parameter, which will be reeferring
+            # visitor method can have a second parameter, which will be referring
             # to the parent.
 
             if new_field and new_field.args:
@@ -316,7 +318,106 @@ def directive_location_to_visitor_method_name(loc: DirectiveLocation):
 
 
 class SchemaDirectiveVisitor(SchemaVisitor):
-    def __init__(self, name, args, visited_type, schema, context):
+    """Base class for custom GraphQL directives.
+
+    Also implements class methods with container and management logic for
+    directives at schema creation time, used by `make_executable_schema`.
+
+    # Lifecycle
+
+    Separate instances of the GraphQL directive are created for each GraphQL
+    schema item with the directive set on it. If directive is set on two
+    fields, two separate instances of a directive will be created.
+
+    # Example schema visitors
+
+    `SchemaDirectiveVisitor` subclasses can implement any of below methods
+    that will be called when directive is applied to different elements of
+    GraphQL schema:
+
+    ```python
+    from ariadne import SchemaDirectiveVisitor
+    from graphql import (
+        GraphQLArgument,
+        GraphQLEnumType,
+        GraphQLEnumValue,
+        GraphQLField,
+        GraphQLInputField,
+        GraphQLInputObjectType,
+        GraphQLInterfaceType,
+        GraphQLObjectType,
+        GraphQLScalarType,
+        GraphQLSchema,
+        GraphQLUnionType,
+    )
+
+    class MyDirective(SchemaDirectiveVisitor):
+        def visit_schema(self, schema: GraphQLSchema) -> None:
+            pass
+
+        def visit_scalar(self, scalar: GraphQLScalarType) -> GraphQLScalarType:
+            pass
+
+        def visit_object(self, object_: GraphQLObjectType) -> GraphQLObjectType:
+            pass
+
+        def visit_field_definition(
+            self,
+            field: GraphQLField,
+            object_type: Union[GraphQLObjectType, GraphQLInterfaceType],
+        ) -> GraphQLField:
+            pass
+
+        def visit_argument_definition(
+            self,
+            argument: GraphQLArgument,
+            field: GraphQLField,
+            object_type: Union[GraphQLObjectType, GraphQLInterfaceType],
+        ) -> GraphQLArgument:
+            pass
+
+        def visit_interface(self, interface: GraphQLInterfaceType) -> GraphQLInterfaceType:
+            pass
+
+        def visit_union(self, union: GraphQLUnionType) -> GraphQLUnionType:
+            pass
+
+        def visit_enum(self, type_: GraphQLEnumType) -> GraphQLEnumType:
+            pass
+
+        def visit_enum_value(
+            self, value: GraphQLEnumValue, enum_type: GraphQLEnumType
+        ) -> GraphQLEnumValue:
+            pass
+
+        def visit_input_object(
+            self, object_: GraphQLInputObjectType
+        ) -> GraphQLInputObjectType:
+            pass
+
+        def visit_input_field_definition(
+            self, field: GraphQLInputField, object_type: GraphQLInputObjectType
+        ) -> GraphQLInputField:
+            pass
+    ```
+    """
+
+    def __init__(self, name, args, visited_type, schema, context) -> None:
+        """Instantiates the directive for schema object.
+
+        # Required arguments
+
+        `name`: a `str` with directive's name.
+
+        `args`: a `dict` with directive's arguments.
+
+        `visited_type`: an GraphQL type this directive is set on.
+
+        `schema`: the GraphQL schema instance.
+
+        `context`: `None`, unused but present for historic reasons.
+        """
+
         self.name = name
         self.args = args
         self.visited_type = visited_type
@@ -324,7 +425,20 @@ class SchemaDirectiveVisitor(SchemaVisitor):
         self.context = context
 
     @classmethod
-    def get_directive_declaration(cls, directive_name: str, schema: GraphQLSchema):
+    def get_directive_declaration(
+        cls, directive_name: str, schema: GraphQLSchema
+    ) -> Optional[GraphQLDirective]:
+        """Get GraphQL directive declaration from GraphQL schema by it's name.
+
+        Returns `GraphQLDirective` object or `None`.
+
+        # Required arguments
+
+        `directive_name`: a `str` with name of directive in the GraphQL schema.
+
+        `schema`: a `GraphQLSchema` instance to retrieve the directive
+        declaration from.
+        """
         return schema.get_directive(directive_name)
 
     @classmethod
@@ -332,7 +446,21 @@ class SchemaDirectiveVisitor(SchemaVisitor):
         cls,
         schema: GraphQLSchema,
         directive_visitors: Dict[str, Type["SchemaDirectiveVisitor"]],
-    ):
+    ) -> Dict[str, GraphQLDirective]:
+        """Get GraphQL directives declaration from GraphQL schema by their names.
+
+        Returns a `dict` where keys are strings with directive names in schema
+        and values are `GraphQLDirective` objects with their declarations in the
+        GraphQL schema.
+
+        # Required arguments
+
+        `directive_name`: a `str` with name of directive in the GraphQL schema.
+
+        `schema`: a `GraphQLSchema` instance to retrieve the directive
+        declaration from.
+        """
+
         declared_directives: Dict[str, GraphQLDirective] = {}
 
         def _add_directive(decl):
@@ -391,6 +519,25 @@ class SchemaDirectiveVisitor(SchemaVisitor):
         *,
         context: Optional[Dict[str, Any]] = None,
     ) -> Mapping[str, List["SchemaDirectiveVisitor"]]:
+        """Apply directives to the GraphQL schema.
+
+        Applied directives mutate the GraphQL schema in place.
+
+        Returns dict with names of GraphQL directives as keys and list of
+        directive instances created for each directive name.
+
+        # Required arguments
+
+        `schema`: a GraphQL schema to which directives should be applied.
+
+        `directive_visitors`: a `dict` with `str` and
+        `Type[SchemaDirectiveVisitor]` pairs defining mapping of
+        `SchemaDirectiveVisitor` types to their names in the GraphQL schema.
+
+        # Optional arguments
+
+        `context`: `None`, unused but present for historic reasons.
+        """
         declared_directives = cls.get_declared_directives(schema, directive_visitors)
 
         #  Map from directive names to lists of SchemaDirectiveVisitor instances
